==> camel-k-model-v1alpha1-6.2.0-sources.jar: io/fabric8/camelk/v1alpha1/KameletBindingListFluent.java <==
package io.fabric8.camelk.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KameletBindingListFluent<A extends KameletBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,KameletBinding item);
  public A setToItems(Integer index,KameletBinding item);
  public A addToItems(io.fabric8.camelk.v1alpha1.KameletBinding... items);
  public A addAllToItems(Collection<KameletBinding> items);
  public A removeFromItems(io.fabric8.camelk.v1alpha1.KameletBinding... items);
  public A removeAllFromItems(Collection<KameletBinding> items);
  public A removeMatchingFromItems(Predicate<KameletBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KameletBinding> getItems();
  public List<KameletBinding> buildItems();
  public KameletBinding buildItem(Integer index);
  public KameletBinding buildFirstItem();
  public KameletBinding buildLastItem();
  public KameletBinding buildMatchingItem(Predicate<KameletBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<KameletBindingBuilder> predicate);
  public A withItems(List<KameletBinding> items);
  public A withItems(io.fabric8.camelk.v1alpha1.KameletBinding... items);
  public Boolean hasItems();
  public KameletBindingListFluent.ItemsNested<A> addNewItem();
  public KameletBindingListFluent.ItemsNested<A> addNewItemLike(KameletBinding item);
  public KameletBindingListFluent.ItemsNested<A> setNewItemLike(Integer index,KameletBinding item);
  public KameletBindingListFluent.ItemsNested<A> editItem(Integer index);
  public KameletBindingListFluent.ItemsNested<A> editFirstItem();
  public KameletBindingListFluent.ItemsNested<A> editLastItem();
  public KameletBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<KameletBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,KameletBindingFluent<KameletBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> camel-k-model-v1alpha1-6.7.2-sources.jar: io/fabric8/camelk/v1alpha1/KameletBindingListFluent.java <==
package io.fabric8.camelk.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KameletBindingListFluent<A extends KameletBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,KameletBinding item);
  public A setToItems(int index,KameletBinding item);
  public A addToItems(io.fabric8.camelk.v1alpha1.KameletBinding... items);
  public A addAllToItems(Collection<KameletBinding> items);
  public A removeFromItems(io.fabric8.camelk.v1alpha1.KameletBinding... items);
  public A removeAllFromItems(Collection<KameletBinding> items);
  public A removeMatchingFromItems(Predicate<KameletBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KameletBinding> getItems();
  public List<KameletBinding> buildItems();
  public KameletBinding buildItem(int index);
  public KameletBinding buildFirstItem();
  public KameletBinding buildLastItem();
  public KameletBinding buildMatchingItem(Predicate<KameletBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<KameletBindingBuilder> predicate);
  public A withItems(List<KameletBinding> items);
  public A withItems(io.fabric8.camelk.v1alpha1.KameletBinding... items);
  public Boolean hasItems();
  public KameletBindingListFluent.ItemsNested<A> addNewItem();
  public KameletBindingListFluent.ItemsNested<A> addNewItemLike(KameletBinding item);
  public KameletBindingListFluent.ItemsNested<A> setNewItemLike(int index,KameletBinding item);
  public KameletBindingListFluent.ItemsNested<A> editItem(int index);
  public KameletBindingListFluent.ItemsNested<A> editFirstItem();
  public KameletBindingListFluent.ItemsNested<A> editLastItem();
  public KameletBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<KameletBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,KameletBindingFluent<KameletBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
